@@ -1,4 +1,4 @@
-maxcurv <-
+maxcurv <- 
 function (x.range, fun, graph = TRUE, ...) 
 {
     stopifnot(is.atomic(x.range))
@@ -10,41 +10,38 @@ function (x.range, fun, graph = TRUE, ...)
         stop("please, reorder 'x.range'.")
     if (!inherits(fun, "function")) 
         stop("'fun' must be a 'function' of x!")
+
+    # first derivative
     dfun <- deriv3(fun2form(fun), "x", func = TRUE)
     if (attr(dfun(x.range[1]), "gradient") == attr(dfun(x.range[2]), 
         "gradient")) 
         stop("'fun' should not be a linar function of x!")
-    b <- lm(range(fun(x.range)) ~ x.range)$coef
-    newx <- seq(x.range[1], x.range[2], length.out = 2000)
-    newy <- fun(newx)
-    if (fun(x.range[1]) > fun(x.range[2])) {
-        si <- -1
-    } else {
-        si <- 1
-    }
-    pred.lm <- mean(fun(x.range)) - si * b[2] * mean(x.range) + 
-        si * b[2] * newx
-    delta <- NULL
-    for (i in 1:length(newy)) {
-        delta[i] <- abs(newy[i] - pred.lm[i])
-    }
-    ind <- which.max(delta)
+
+    # gradient and hessian
+    x <- seq(x.range[1], x.range[2], length.out = 2000)
+    gr <- attr(dfun(x), "gradient")
+    he <- attr(dfun(x), "hessian")[,, "x"]
+    k <- abs(he) / (1 + gr^2)^(3/2)
+    mcp <- x[which.max(k)]
+
+    # graph
     if (graph) {
-        x <- NULL
-        curve(fun(x), from = x.range[1], to = x.range[2],
-            main = "Maximum curvature point", las = 1, ...)
-        lines(x = c(newx[ind], newx[ind]),
-            y = c(-1e+20, newy[ind]), lty = 3)
-        lines(x = c(-1e+20, newx[ind]),
-            y = c(newy[ind], newy[ind]), lty = 3)
+        curve(fun, from = x.range[1], to = x.range[2], ...)
+        lines(x = c(mcp, mcp, -9e9), 
+           y = c(-9e9, fun(mcp), fun(mcp)), lty = 3)
+        devAskNewPage(ask = TRUE)
+        plot(x, k, type = "l", ...)
+        lines(x = c(mcp, mcp, -9e9), 
+           y = c(-9e9, max(k), max(k)), lty = 3)
     }
- 
-    out <- list(fun = deparse(fun)[2], x0 = newx[ind], y0 = newy[ind])
+
+    # output
+    out <- list(fun = deparse(fun)[2], 
+       x0 = mcp, y0 = fun(mcp))
     class(out) <- "maxcurv"
     return(out)
 }
 
-
 # -------------------------------------------
 # print method
 print.maxcurv <- 
